=======
Authors
=======

**Authors**:

* Dario d'Andrea, dariod@playtika.com

|

**Contributors**:

* Armand Valsesia, armandv@playtika.com
* Jerome Carayol, jeromec@playtika.com
* Yves Lamonato, yvesl@playtika.com
